from typing import List, Literal

from encord_active_components.renderer import Components, render

Scope = Literal["data_quality", "label_quality", "model_quality"]


def explorer(project_name: str, items: List[str], scope: Scope):
    return render(
        component=Components.EXPLORER,
        props={"projectName": project_name, "items": items, "scope": scope},
    )



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['encord_active_components', 'encord_active_components.components']

package_data = \
{'': ['*'],
 'encord_active_components': ['frontend/*',
                              'frontend/assets/*',
                              'frontend/dist/*',
                              'frontend/dist/assets/*']}

install_requires = \
['streamlit>=1.19.0,<2.0.0']

setup_kwargs = {
    'name': 'encord-active-components',
    'version': '0.0.10',
    'description': 'Frontend components used by Encord Active',
    'long_description': 'None',
    'author': 'Cord Technologies Limited',
    'author_email': 'hello@encord.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9, !=2.7.*, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*, !=3.5.*, !=3.6.*, !=3.7.*, !=3.8.*',
}


setup(**setup_kwargs)



from enum import Enum
from typing import List, Optional, Tuple, TypedDict, Union

from encord_active_components.components.projects_page import Project, ProjectStats
from encord_active_components.renderer import Components, render


class MenuItem(TypedDict):
    key: str
    label: str
    children: Optional[List["MenuItem"]]


class OutputAction(str, Enum):
    VIEW_ALL_PROJECTS = "VIEW_ALL_PROJECTS"
    SELECT_PROJECT = "SELECT_PROJECT"
    SELECT_PAGE = "SELECT_PAGE"


def pages_menu(
    items: List[MenuItem],
    projects: List[Project],
    initial_key: str,
    selected_project_hash: str,
) -> Tuple[OutputAction, Union[str, None]]:
    return render(
        component=Components.PAGES_MENU,
        props={
            "items": items,
            "projects": projects,
            "selectedProjectHash": selected_project_hash,
            "initialKey": initial_key,
        },
    )


if __name__ == "__main__":
    ITEMS: List[MenuItem] = [
        {
            "key": "Example 1",
            "label": "Example 1",
            "children": [
                {"key": "Example 1#Summary", "label": "Summary", "children": None},
                {"key": "Example 1#Explorer", "label": "Explorer", "children": None},
            ],
        },
        {
            "key": "Example 2 ",
            "label": "Example 2 ",
            "children": [
                {"key": "Example 2 #Summary", "label": "Summary", "children": None},
                {"key": "Example 2 #Explorer", "label": "Explorer", "children": None},
            ],
        },
    ]
    PROJECTS = [
        Project(
            name="Foo",
            hash="d3d81fb8-634c-4909-be57-49f94adc93dd",
            path=None,
            sandbox=True,
            stats=ProjectStats(dataUnits=1000, labels=14566, classes=8),
            imageUrl="",
        ),
        Project(
            name="Bar",
            hash="603336c6-c5c4-4ae9-87a7-216e5201ede5",
            path=None,
            sandbox=True,
            stats=ProjectStats(dataUnits=100, labels=166, classes=2),
            imageUrl="",
        ),
    ]
    key, action = pages_menu(ITEMS, PROJECTS, PROJECTS[0]["hash"], ITEMS[0]["key"])
